package v1_0

import (
	"net/http"

	"adm-gateway/errors"
	"adm-gateway/parser"

	param_v1 "adm-gateway/param/v1"
	"github.com/aliyun/aliyun-oss-go-sdk/oss"
	"github.com/gin-gonic/gin"
	"git.getensh.com/common/gopkgsv2/tasker/httptasker"
)

// Upload godoc
// @Summary 上传图片
// @Description 上传图片
// @Tags upload,v1.0
// @Accept  json
// @Produce  json
// @Param token header string true "jwt token"
// @Param file formData file true "图片"
// @Param id formData string true "brand_id/series_id"
// @Param type formData int true "类型 1:brand 2:series"
// @Success 200 {string} json "{}"
// @Failure 500 {object} base.HTTPError
// @Router /api/v1.0/upload/ [post]
func (c *Controller) Upload(ctx *gin.Context) {
	uploadImageTask := func() error {
		file, err := ctx.FormFile("file")
		if err != nil {
			return errors.SystemError
		}

		if file.Header.Get("content-type") != "image/png" {
			return errors.FileTypeError
		}

		if file.Size > 1<<20 {
			return errors.FileToLargestError
		}

		path := ""

		switch ctx.PostForm("type") {
		case "1":
			path = "brand-img"
		case "2":
			path = "series-m"
		default:
			return errors.UploadTypeError
		}

		client, err := oss.New(
			parser.Conf.Oss.EndPoint,
			parser.Conf.Oss.AccessKey,
			parser.Conf.Oss.AccessSecret,
		)
		if err != nil {
			return err
		}

		bucket, err := client.Bucket(parser.Conf.Oss.Bucket)
		if err != nil {
			return err
		}

		reader, _ := file.Open()

		err = bucket.PutObject(path+"/"+ctx.PostForm("id")+".png", reader)
		if err != nil {
			return err
		}

		ctx.JSON(http.StatusOK, &param_v1.UpdateBrandResponse{})
		return nil
	}
	// 执行任务
	httptasker.Exec(ctx, uploadImageTask)
}
