package v1

import (
	"adm-gateway/param/base"
	v1 "adm-gateway/pb/v1"
)

// 1. 数据管理表 t_adm_data_management

type GetDataListQuery struct {
	TableName string `form:"table_name" json:"table_name"`
	Desc      string `form:"desc"       json:"desc"`
	Level     string `form:"level"      json:"level"`
	Page      int32  `form:"page"       json:"page"`
	PageSize  int32  `form:"page_size"  json:"page_size"`
}

type GetDataListRequest struct {
	base.Header
	GetDataListQuery
}

type GetDataListResponse struct {
	base.Result
	Data *v1.DataListReply `json:"dataList"`
}

// 数据搜索列表

type SearchDataQuery struct {
	TableName string `json:"table_name" form:"table_name"`
}

type SearchDataRequest struct {
	base.Header
	SearchDataQuery
}

type SearchDataResponse struct {
	base.Result
	Data *v1.SearchDataReply `json:"data"`
}

// 所属层搜索列表

type SearchLevelQuery struct {
	Level string `json:"level" form:"level"`
}

type SearchLevelRequest struct {
	base.Header
	SearchLevelQuery
}

type SearchLevelResponse struct {
	base.Result
	Data []string `json:"data"`
}

// 2.数据关系表 t_adm_task_data_relation

type GetRelationQuery struct {
	SourceCode string `form:"source_code" json:"source_code"`
}

type GetRelationRequest struct {
	base.Header
	GetRelationQuery
}

type GetRelationResponse struct {
	base.Result
	Data *v1.RelationReply `json:"relationData"`
}

// 任务开关

type GetSwitchBody struct {
	TaskId int64 `form:"task_id"    json:"task_id"`
	IsOn   bool  `form:"is_on"      json:"is_on"`
}

type GetSwitchRequest struct {
	base.Header
	GetSwitchBody
}

type GetSwitchResponse struct {
	base.Result
}

// 3.任务管理表 t_adm_tasks_management

type GetTaskListQuery struct {
	TaskName string `form:"task_name" json:"task_name"`
	Desc     string `form:"desc"      json:"desc"`
	Page     int32  `form:"page"      json:"page"`
	PageSize int32  `form:"page_size" json:"page_size"`
}

type GetTaskListRequest struct {
	base.Header
	GetTaskListQuery
}

type GetTaskListResponse struct {
	base.Result
	Data *v1.TaskListReply `json:"taskList"`
}

// 任务搜索列表

type SearchTaskQuery struct {
	TaskName string `json:"task_name" form:"task_name"`
}

type SearchTaskRequest struct {
	base.Header
	SearchTaskQuery
}

type SearchTaskResponse struct {
	base.Result
	Data *v1.SearchTaskReply `json:"data"`
}

// 4.依赖表 t_adm_task_dependency

type GetDependencyQuery struct {
	TaskId int64 `form:"task_id" json:"task_id"`
	Type   int32 `form:"type"    json:"type"`
}

type GetDependencyRequest struct {
	base.Header
	GetDependencyQuery
}

type GetDependencyResponse struct {
	base.Result
	Data *v1.DependencyReply `json:"dependencyData"`
}

// DataSourceRelation

type GetDataSourceRelationQuery struct {
	SourceCode string `form:"source_code" json:"source_code"`
	TaskId     int64  `form:"task_id"     json:"task_id"`
}

type GetDataSourceRelationRequest struct {
	base.Header
	GetDataSourceRelationQuery
}

type GetDataSourceRelationResponse struct {
	base.Result
	Data *v1.DataSourceRelationReply `json:"data"`
}

// 手动任务列表 t_adm_offline_task

type GetManualTaskQuery struct {
	Source         string `form:"source"           json:"source"`
	TaskName       string `form:"task_name"        json:"task_name"`
	ManualTaskName string `form:"manual_task_name" json:"manual_task_name"`
	Time1          int64  `form:"time1"            json:"time1"`
	Time2          int64  `form:"time2"            json:"time2"`
	Page           int32  `form:"page"             json:"page"`
	PageSize       int32  `form:"page_size"        json:"page_size"`
}

type GetManualTaskRequest struct {
	base.Header
	GetManualTaskQuery
}

type GetManualTaskResponse struct {
	base.Result
	Data *v1.ManualTaskReply `json:"manualTaskData"`
}

// 源表搜索列表

type SourceQuery struct {
	SourceName string `json:"source_name" form:"source_name"`
}

type SourceRequest struct {
	base.Header
	SourceQuery
}

type SourceResponse struct {
	base.Result
	Data *v1.SourceReply `json:"data"`
}

// 任务列表

type TaskQuery struct {
	SourceRequest string `json:"source_request" form:"source_request"`
}

type TaskRequest struct {
	base.Header
	TaskQuery
}

type TaskResponse struct {
	base.Result
	Data *v1.TaskReply `json:"data"`
}

// 创建手动任务

type CreateBody struct {
	TaskName string   `form:"task_name"    json:"task_name"`
	Type     int64    `form:"type"         json:"type"`
	Source   string   `form:"source"       json:"source"`
	Sql      string   `form:"sql"          json:"sql"`
	TaskIds  []string `form:"task_ids"     json:"task_ids"`
}

type CreateRequest struct {
	base.Header
	CreateBody
}

type CreateResponse struct {
	base.Result
}

// 上传

type UploadFileBody struct {
	TaskName string `form:"task_name"    json:"task_name"`
}

type UploadFileRequest struct {
	base.Header
	UploadFileBody
}

type UploadFileResponse struct {
	base.Result
	Data *v1.UploadFileReply `json:"data"`
}

// 字段管理表 t_adm_field_management

type GetFieldListQuery struct {
	Field    string `form:"field"      json:"field"`
	Desc     string `form:"desc"       json:"desc"`
	Page     int32  `form:"page"       json:"page"`
	PageSize int32  `form:"page_size"  json:"page_size"`
}

type GetFieldListRequest struct {
	base.Header
	GetFieldListQuery
}

type GetFieldListResponse struct {
	base.Result
	Data *v1.FieldReply `json:"data"`
}

// 导出EXCEL

type ExcelQuery struct {
}

type ExcelRequest struct {
	base.Header
	ExcelQuery
}

type ExcelResponse struct {
	base.Result
	Data *v1.ExcelReply `json:"data"`
}

// API管理表 t_adm_api_management

type GetAPIListQuery struct {
	ApiNo    string `form:"api_no"     json:"api_no"`
	Desc     string `form:"desc"       json:"desc"`
	Page     int32  `form:"page"       json:"page"`
	PageSize int32  `form:"page_size"  json:"page_size"`
}

type GetAPIListRequest struct {
	base.Header
	GetAPIListQuery
}

type GetAPIListResponse struct {
	base.Result
	Data *v1.APIListReply `json:"data"`
}

// 查看API

type GetCheckAPIQuery struct {
	ApiId int64 `form:"api_id"     json:"api_id"`
}

type GetCheckAPIRequest struct {
	base.Header
	GetCheckAPIQuery
}

type GetCheckAPIResponse struct {
	base.Result
	Data *v1.CheckAPIReply `json:"data"`
}

// 删除API

type GetDeleteAPIPath struct {
	ApiId int64 `uri:"api_id"     json:"api_id"`
}

type GetDeleteAPIRequest struct {
	base.Header
	GetDeleteAPIPath
}

type GetDeleteAPIResponse struct {
	base.Result
}

// 密钥管理表 t_adm_api_management

type GetKeyListQuery struct {
	Key      string `form:"key"        json:"key"`
	Desc     string `form:"desc"       json:"desc"`
	Page     int32  `form:"page"       json:"page"`
	PageSize int32  `form:"page_size"  json:"page_size"`
}

type GetKeyListRequest struct {
	base.Header
	GetKeyListQuery
}

type GetKeyListResponse struct {
	base.Result
	Data *v1.KeyListReply `json:"data"`
}

// 新增密钥

type CreateKeyBody struct {
	Desc string `form:"desc"    json:"desc"`
}

type CreateKeyRequest struct {
	base.Header
	CreateKeyBody
}

type CreateKeyResponse struct {
	base.Result
}

// 删除密钥

type DeleteKeyPath struct {
	Key string `uri:"key"    json:"key"`
}

type DeleteKeyRequest struct {
	base.Header
	DeleteKeyPath
}

type DeleteKeyResponse struct {
	base.Result
}

// API列表

type AllAPIQuery struct {
	AllAPI string `json:"all_api" form:"all_api"`
}

type AllAPIRequest struct {
	base.Header
	AllAPIQuery
}

type AllAPIResponse struct {
	base.Result
	Data *v1.AllAPIReply `json:"data"`
}

// 密钥列表

type AllKeyQuery struct {
	AllKey string `json:"all_key" form:"all_key"`
}

type AllKeyRequest struct {
	base.Header
	AllKeyQuery
}

type AllKeyResponse struct {
	base.Result
	Data []string `json:"data"`
}

// API查询

type UseAPIQuery struct {
	ApiId int64 `form:"api_id"     json:"api_id"`
}

type UseAPIRequest struct {
	base.Header
	UseAPIQuery
}

type UseAPIResponse struct {
	base.Result
	Data *v1.UseAPIReply `json:"data"`
}

// 查看表结构

type TableStructQuery struct {
	TableName string `json:"table_name" form:"table_name"`
}

type TableStructRequest struct {
	base.Header
	TableStructQuery
}

type TableStructResponse struct {
	base.Result
	Data *v1.TableStructReply `json:"data"`
}

// 车型映射管理

type StyleMapQuery struct {
	Source       string `form:"source"     json:"source"`
	State        int64  `form:"state"       json:"state"`
	ThirdStyleId string `form:"third_style_id"      json:"third_style_id"`
	StyleId      string `form:"style_id"      json:"style_id"`
	Page         int32  `form:"page"       json:"page"`
	PageSize     int32  `form:"page_size"  json:"page_size"`
}

type StyleMapRequest struct {
	base.Header
	StyleMapQuery
}

type StyleMapResponse struct {
	base.Result
	Data *v1.StyleMapReply `json:"data"`
}

// 编辑

type EditMapBody struct {
	ThirdStyleId string `form:"third_style_id"          json:"third_style_id"`
	StyleId      string `form:"style_id"                json:"style_id"`
}

type EditMapRequest struct {
	base.Header
	EditMapBody
}

type EditMapResponse struct {
	base.Result
	Data *v1.EditMapReply `json:"data"`
}

// 映射源列表

type AllSourceQuery struct {
	AllSource string `json:"all_source" form:"all_source"`
}

type AllSourceRequest struct {
	base.Header
	AllSourceQuery
}

type AllSourceResponse struct {
	base.Result
	Data []string `json:"data"`
}

// 信息公告

type GetAnnouncementQuery struct {
	VinRule   string `json:"vin_rule" form:"vin_rule"`
	BrandName string `json:"brand_name" form:"brand_name"`
	ModelNo   string `json:"model_no" form:"model_no"`
	Page      int32  `form:"page"       json:"page"`
	PageSize  int32  `form:"page_size"  json:"page_size"`
}

type GetAnnouncementRequest struct {
	base.Header
	GetAnnouncementQuery
}

type GetAnnouncementResponse struct {
	base.Result
	Data *v1.AnnouncementReply `json:"data"`
}

// 编辑

type GetEditQuery struct {
	VehicleBatch string `json:"vehicle_batch" form:"vehicle_batch"`
	ModelNo      string `json:"model_no" form:"model_no"`
}

type GetEditRequest struct {
	base.Header
	GetEditQuery
}

type GetEditResponse struct {
	base.Result
	Data *v1.EditReply `json:"data"`
}

// 数据导入模板

type DataImportTemplateQuery struct {
	TemplateName string `form:"template_name" json:"template_name"`
	Page         int32  `form:"page"       json:"page"`
	PageSize     int32  `form:"page_size"  json:"page_size"`
}

type DataImportTemplateRequest struct {
	base.Header
	DataImportTemplateQuery
}

type DataImportTemplateResponse struct {
	base.Result
	Data *v1.DataImportTemplateReply `json:"data"`
}

// 新建模板

type CreateTemplateBody struct {
	TemplateName string   `form:"template_name" json:"template_name"`
	Request      []string `form:"request" json:"request"`
	TaskName     []string `form:"task_name" json:"task_name"`
}

type CreateTemplateRequest struct {
	base.Header
	CreateTemplateBody
}

type CreateTemplateResponse struct {
	base.Result
}

// 修改模板

type EditTemplateBody struct {
	Id           int64    `form:"id" json:"id"`
	TemplateName string   `form:"template_name" json:"template_name"`
	Request      []string `form:"request" json:"request"`
	TaskName     []string `form:"task_name" json:"task_name"`
}

type EditTemplateRequest struct {
	base.Header
	EditTemplateBody
}

type EditTemplateResponse struct {
	base.Result
}

// 删除模板

type DeleteTemplatePath struct {
	Id int64 `uri:"id" json:"id"`
}

type DeleteTemplateRequest struct {
	base.Header
	DeleteTemplatePath
}

type DeleteTemplateResponse struct {
	base.Result
}

// 数据导入

//type DataImport struct {
//	Request string `form:"request" json:"request"`
//	Value   string `form:"value" json:"value"`
//}

type DataImportBody struct {
	Id          int64            `form:"id" json:"id"`
	RequestList []*v1.DataImport `form:"request_list" json:"request_list"`
}

type DataImportRequest struct {
	base.Header
	DataImportBody
}

type DataImportResponse struct {
	base.Result
}

// 更新API信息

type UpdateAPIBody struct {
	Api   string `form:"api"   json:"api"`
	Param string `form:"param" json:"param"`
	Data  string `form:"data" json:"data"`
}

type UpdateAPIRequest struct {
	base.Header
	UpdateAPIBody
}

type UpdateAPIResponse struct {
	base.Result
}
