// Copyright 2019 getensh.com. All rights reserved.
// Use of this source code is governed by getensh.com.

package route

import (
	"net/http"

	"github.com/gin-gonic/gin"

	v1 "adm-gateway/controller/v1.0"
	_ "adm-gateway/docs"
	"adm-gateway/route/middleware"
)

func SetupRoute(engine *gin.Engine) {
	// 404页面
	engine.NoRoute(func(c *gin.Context) {
		c.String(http.StatusNotFound, "Not Found")
	})

	// 服务健康检查
	engine.GET("/ping", func(c *gin.Context) {
		c.String(http.StatusOK, "pong")
	})

	// version 1.0
	apiv1_0 := engine.Group("/api/v1.0")
	{
		c := v1.NewController()
		engine.POST("/api/v1.0/login", c.Login)

		// 以下都需要token校验
		apiv1_0.Use(middleware.Jwt())
		brand := apiv1_0.Group("/brand")
		{
			brand.GET("/", c.Brand)
			brand.GET("/search", c.Search)
			brand.PUT("/", c.UpdateBrand)
			brand.GET("/maker", c.Maker)
			brand.PUT("/maker", c.UpdateMaker)
		}
		series := apiv1_0.Group("/series")
		{
			series.GET("/", c.Series)
			series.PUT("/", c.UpdateSeries)
		}
		style := apiv1_0.Group("style")
		{
			style.GET("/", c.StyleList)
			style.PUT("/", c.UpdateStyle)
			style.GET("/config/:id", c.StyleInfo)
			style.PUT("/config/", c.UpdateStyleConfig)
			style.GET("/export", c.ExportStyle)
			style.GET("/export_task", c.ExportStyleTaskList)
			style.DELETE("/export_task/:id", c.DeleteExportStyleTask)
		}

		dataManagement := apiv1_0.Group("/data_management")
		{
			dataManagement.GET("/", c.DataList)
			dataManagement.GET("/table_struct", c.TableStruct)
			dataManagement.GET("/relation", c.Relation)
			dataManagement.GET("/search", c.SearchData)
			dataManagement.GET("/search_level", c.SearchLevel)
			dataManagement.PUT("/relation/", c.Switch)
		}

		taskManagement := apiv1_0.Group("/task_management")
		{
			taskManagement.GET("/", c.TaskList)
			taskManagement.GET("/dependency", c.Dependency)
			taskManagement.GET("/search", c.SearchTask)
			taskManagement.GET("/relation", c.DataSourceRelation)
		}

		upload := apiv1_0.Group("/upload")
		{
			upload.POST("/", c.Upload)
		}

		maintainace := apiv1_0.Group("/maintainace")
		{
			maintainace.GET("/manual", c.GetMaintainaceManual)
			maintainace.GET("/item_list", c.GetItemList)
			maintainace.PUT("/manual", c.UpdateManual)
			maintainace.GET("/info", c.GetMaintainaceManualInfo)
			maintainace.GET("/style_item", c.GetStyleItem)
			maintainace.GET("/c2/list", c.GetC2List)
			maintainace.PUT("/style_item", c.UpdateStyleItem)
			maintainace.DELETE("/manual/:id", c.DeleteMaintainace)
			maintainace.DELETE("/style_item/:id", c.DeleteStyleItem)
		}

		manualTask := apiv1_0.Group("/manual_task")
		{
			manualTask.GET("/", c.ManualTask)
			manualTask.GET("/source", c.Source)
			manualTask.GET("/task", c.Task)
			manualTask.POST("/create", c.Create)
			manualTask.POST("/create/upload", c.UploadFile)
		}

		field := apiv1_0.Group("/field")
		{
			field.GET("/", c.Field)
			field.GET("/excel", c.Excel)
		}

		api := apiv1_0.Group("/api")
		{
			api.GET("/", c.APIList)
			api.GET("/check", c.CheckAPI)
			api.DELETE("/delete/:api_id", c.DeleteAPI)
			api.GET("/key", c.KeyList)
			api.POST("/key/create", c.CreateKey)
			api.DELETE("/delete/key/:key", c.DeleteKey)
			api.GET("/search/all_api", c.AllAPI)
			api.GET("/search/all_key", c.AllKey)
			api.GET("/use_key", c.UseAPI)
			api.PUT("/update_api", c.UpdateAPI)
		}

		styleMapManagement := apiv1_0.Group("/style_map_management")
		{
			styleMapManagement.GET("/", c.StyleMap)
			styleMapManagement.PUT("/", c.EditMap)
			styleMapManagement.GET("/all_source", c.AllSource)
		}

		announcement := apiv1_0.Group("/announcement")
		{
			announcement.GET("/", c.AnnouncementList)
			announcement.GET("/edit", c.EditList)
		}

		dataImport := apiv1_0.Group("/data_import")
		{
			dataImport.GET("/data_import_template", c.DataImportTemplate)
			dataImport.POST("/create_template", c.CreateTemplate)
			dataImport.PUT("/edit_template", c.EditTemplate)
			dataImport.DELETE("/delete_template/:id", c.DeleteTemplate)
			dataImport.POST("/data_import", c.DataImport)
		}

		template := apiv1_0.Group("/template")
		{
			template.GET("/list", c.TemplateList)
			template.GET("/detail/list", c.TemplateDetailList)
			template.GET("/detail", c.TemplateDetail)
			template.PUT("/detail", c.UpdateTemplateDetail)
			template.POST("/detail", c.AddTemplateDetail)
			template.POST("/detail/choose", c.ChooseTemplateDetail)
			template.GET("/item_list", c.GetTemplateItemList)
		}

	}
}
